@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.3
+# Version   : 0.2.4
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -452,7 +452,7 @@ class AFM:
         '''
         Function to plot import Nanosurf .nid data files.
         '''
-        _nid = ns.read(filename)
+        _nid = ns.read(self.file_name)
         _data = _nid.data
         _params = _nid.param
 
